Re-exports
pub use finder::NodeProjectFinder;
Modules
Enums
- Package
Manager - Represents the detected Node.js package manager
Functions
- detect_
package_ manager - Detects the package manager by checking for lock files in the given directory Priority: bun.lockb > pnpm-lock.yaml > yarn.lock > package-lock.json > npm (default)
- detect_
package_ manager_ recursive - Detects the package manager by searching from the given path up to the root